# Create Components

Panel components are the building blocks and visual layouts of your app or dashboard. These How-to pages provide solutions for common tasks related to creating and customizing components.

## Initialize and Access Components

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1` Construct Panes
:link: construct_panes
:link-type: doc

How to construct Pane objects for displaying visible components.
:::

:::{grid-item-card} {octicon}`unverified;2.5em;sd-mr-1` Access Pane Type
:link: pane_type
:link-type: doc

How to access Pane Type.
:::

:::{grid-item-card} {octicon}`telescope;2.5em;sd-mr-1` Access Widget Values
:link: widget_values
:link-type: doc

How to access and set widget values.
:::

:::{grid-item-card} {octicon}`file-diff;2.5em;sd-mr-1` Add or Remove Components
:link: add_remove
:link-type: doc

How to add or remove components from a panel.
:::
::::

## Style Components

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`gift;2.5em;sd-mr-1` Apply CSS
:link: apply_css
:link-type: doc

How to apply custom CSS styling.
:::

:::{grid-item-card} {octicon}`hourglass;2.5em;sd-mr-1` Customize Loading Icon
:link: load_icon
:link-type: doc

How to customize the loading icon.
:::

:::{grid-item-card} {octicon}`eye;2.5em;sd-mr-1` Control Visibility
:link: visibility
:link-type: doc

How to control the visibility of a component.
:::

::::

## Arrange and Size Components

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`mirror;2.5em;sd-mr-1` Customize Spacing
:link: spacing
:link-type: doc

How to customize the spacing between elements.
:::

:::{grid-item-card} {octicon}`project;2.5em;sd-mr-1` Align Components
:link: align
:link-type: doc

How to customize the alignment between components.
:::

:::{grid-item-card} {octicon}`filter;2.5em;sd-mr-1` Control Size
:link: size
:link-type: doc

How to control the size of components.
:::

::::


```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

construct_panes
pane_type
add_remove
apply_css
load_icon
visibility
spacing
align
size
```
